
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
PayPal
Rolsky
Rolsky's
AO
Aghem
Ahad
Akan
Alatsinainy
Aneg
Asturian
Asu
Atini
Atinni
Atsam
Auer
Axad
Aynas
BCE
BD
BH
BJ
BQ
BT
BW
BZ
Bafia
Balaza
Bambara
Barthélemy
Basaa
Belarusian
Bemba
Bena
Blin
Bodo
Bokmål
Burkina
Bïkua
CLDR
CN
CX
Caicos
Ceuta
Chiga
Chiini
Chiposi
Chumapiri
Chumatato
Colognian
Comlaa
Costa
Curaçao
Cyrl
Côte
DG
DK
DM
Deseret
DiLuain
Dilbata
Dimingu
Divehi
Domhnaigh
Duala
Dwowda
Dydd
Dzo
Dzongkha
Dzu
Dé
EEE
EEEE
EEEEd
EEEd
EG
EHm
EHms
Eg
Ehm
Ehms
Embu
Etleeni
Ewondo
FJ
FK
Faroe
Faroese
Faso
Fonyi
Friulian
Fulah
Futuna
GF
GG
GGGG
GGGGy
GGGGyMMMMEEEEdd
GGGGyMd
GGGGyyyyMMMMd
GH
GN
GQ
GW
GY
Galician
Ganda
Geez
Gurmukhi
Gusii
Gy
GyM
GyMMM
GyMMMEEEEd
GyMMMEd
GyMMMM
GyMMMMEd
GyMMMMd
GyMMMd
H'h'mm
H'h'mm'min'ss
HH'h'mm
HHmm
HHmmZ
HHmmss
HK
HN
Hant
Hm
Hmm
Hms
Hmsv
Hmsvvvv
Hmv
Hong
IC
IM
ISonto
Igbo
Ijumatatu
Il
Inari
Interlingua
Isniin
Isnin
Ituku
JE
JM
Je
Jedoonee
Jelhein
Jiec
Jiyax
Jju
Jola
Jumaatatu
Jumamosi
Jumapil
Jumapili
Jumapiri
Jumapílí
Jumatatu
Jumatatuu
Jumatátu
KE
KH
KZ
Kabuverdianu
Kabyle
Kako
Kalaallisut
Kalenjin
Kamba
Kashmiri
Katanga
Kinyarwanda
Kitts
Kiumia
Konkani
Koro
Kosovo
Kotaai
Kotisap
Koyra
Koyraboro
Kpelle
Ku
Kubacha
Kuramuka
Kuwa
Kwasio
Kyrgyz
LK
LLL
LLLL
LY
Lakota
Langi
Lanka
Latn
Leone
Leste
Liduva
Lingala
Linggo
Lintani
Litini
Litinin
Llun
Lolemba
Luain
Luba
Lun
Lunes
Luns
Luri
Luxembourgish
Luyia
Lāpule
MEEEEd
MEd
MF
MH
MMM
MMMEEEEd
MMMEEEd
MMMEd
MMMM
MMMMEEEEd
MMMMEEEd
MMMMEd
MMMMd
MMMMdd
MMMd
MMMdd
MMd
MMdd
MQ
MX
MZ
Maandag
Maarten
Macau
Machame
Magyarország
Makhuwa
Makonde
Mantaxtsees
Marino
Mayen
Mayotte
Mazanderani
Mdd
Mderot
Meetto
Melilla
Meru
Minggu
Miquelon
Mmantaha
Montag
Moondaach
Morisyen
Mosopulogo
Mosupalogo
Msombuluko
Mundang
Muramuko
Musumbhunuku
Musumbuluwo
Muvhuro
Mvulo
Mäntag
Määntig
Méindeg
Mōnite
Mọnde
NG
Nakaebarasa
Nakaejuma
Nama
Ndebele
Ngiemboon
Ngomba
Niue
Njumatatu
Njumatatũ
Nkodya
Nuer
Nyanja
Nyankole
Nynorsk
Occitan
Oromo
Orwokubanza
Ossetic
PN
PREEURO
PY
Palau
Palichimo
Papua
Pashto
Pazartesi
Ponedjeljak
Príncipe
Puerto
QA
QQQ
QQQQ
QQQy
Qidaame
Qunxa
Rica
Ridas
Rombo
Rundi
Rwa
Réunion
SAR
SX
SY
SZ
Sabato
Sabti
Saho
Sambat
Samburu
Sami
Sanass
Sanbata
Sango
Sangu
Sanyo
Sena
Senin
Senni
Serbo
Shambala
Shona
Sichuan
Sidamo
Sinhala
Sint
Soga
Sondag
Sonto
Sorbian
Sotho
Sri
Sul
Svondo
Swati
São
T'Q
TG
TT
TW
TZ
Tachelhit
Taita
Tajik
Tamazight
Tanii
Taroko
Tasawaq
Tene
Teso
Tfng
Tich
Tifinagh
Tigre
Tigrinya
Timor
Tnejn
Tokelau
Tomé
Tsonga
Tunga
Turkmen
Tyap
UA
UMsombuluko
UY
Uhr
Uyghur
VC
VE
VN
VU
Vaii
Valencian
Venda
Volapük
Vunjo
WF
WS
Wa
Wai
Walamo
Walser
Wiixata
Wolof
Wuok
XK
Yangben
Yi
ZA
ZM
ZW
Zarma
Zealand
aa
aba
akahi
astelehena
ataasinngorneq
aynas
bazar
ccc
cccc
cldr
d'mh
dal
del
di
dilluns
diluns
dimanche
domingo
dushanba
duşem
dy
dzo
dä
d’Ivoire
ek
ert
esmaspäev
feira
fera
glindesdi
gumba
gwà
hai
hh
hhmm
hhmmss
hm
hmm
hmmss
hms
hmsv
hmsvvvv
hmv
hodź
hétfő
hënë
iyax
jimweri
jiyax
jumwa
kuni
kvartal
kwambĩlĩlya
kyumwa
lia
libosó
lindi
llunes
lundi
lundo
lunedi
lunedì
lunes
luni
lunis
ly
lyatatu
maanantai
maanantaina
maandag
mandag
mbere
mm'min'ss
mmss
moandei
mok
mvfò
mwa
mánadagur
mánudagur
måanta
måndag
móndie
nde
ndí
ngày
nja
nt
năm
pirmadienis
pirmdiena
pondelok
pondělí
ponedeljak
ponedeljek
ponedjeljak
poniedzia
pétuwa
pétuwakȟa
póndźela
pónjeźele
sabaat
segunda
shahuviluha
sigunda
sngayan
ss
sublasses
sunnudagur
tgKingal
tháng
trimestrul
tsu
uMsombuluko
uMvulo
ukpà
urteko
vuossargâ
vuossárga
vvvv
wa
yG
yM
yMEEEEd
yMEd
yMM
yMMM
yMMMEEEEd
yMMMEd
yMMMM
yMMMMEEEEd
yMMMMEd
yMMMMccccd
yMMMMd
yMMMd
yMMdd
yMd
yQ
yQQQ
yQQQQ
yakshanba
yambo
yy
yyM
yyMM
yyMMM
yyMMMEEEd
yyMMMd
yyMMdd
yyQ
yyQQQQ
yyyy
yyyyLLLL
yyyyM
yyyyMEEEd
yyyyMM
yyyyMMM
yyyyMMMM
yyyyMMMMEEEEd
yyyyQQQQ
zeg
zh
Åland
ûse
ži
Ọjọ
Dave
autarch
lib
DateTime
Locale
Base
Catalog
Conflicts
Data
FromData
Util
af
af_NA
af_ZA
agq
agq_CM
ak
ak_GH
am
am_ET
ar
ar_001
ar_AE
ar_BH
ar_DJ
ar_DZ
ar_EG
ar_EH
ar_ER
ar_IL
ar_IQ
ar_JO
ar_KM
ar_KW
ar_LB
ar_LY
ar_MA
ar_MR
ar_OM
ar_PS
ar_QA
ar_SA
ar_SD
ar_SO
ar_SS
ar_SY
ar_TD
ar_TN
ar_YE
as
as_IN
asa
asa_TZ
ast
ast_ES
az
az_Cyrl
az_Cyrl_AZ
az_Latn
az_Latn_AZ
bas
bas_CM
be
be_BY
bem
bem_ZM
bez
bez_TZ
bg
bg_BG
bm
bm_ML
bn
bn_BD
bn_IN
bo
bo_CN
bo_IN
br
br_FR
brx
brx_IN
bs
bs_Cyrl
bs_Cyrl_BA
bs_Latn
bs_Latn_BA
ca
ca_AD
ca_ES
ca_ES_VALENCIA
ca_FR
ca_IT
ce
ce_RU
cgg
cgg_UG
chr
chr_US
ckb
ckb_IQ
ckb_IR
cs
cs_CZ
cu
cu_RU
cy
cy_GB
da
da_DK
da_GL
dav
dav_KE
de
de_AT
de_BE
de_CH
de_DE
de_LI
de_LU
dje
dje_NE
dsb
dsb_DE
dua
dua_CM
dyo
dyo_SN
dz
dz_BT
ebu
ebu_KE
ee
ee_GH
ee_TG
el
el_CY
el_GR
en
en_001
en_150
en_AG
en_AI
en_AS
en_AT
en_AU
en_BB
en_BE
en_BI
en_BM
en_BS
en_BW
en_BZ
en_CA
en_CC
en_CH
en_CK
en_CM
en_CX
en_CY
en_DE
en_DG
en_DK
en_DM
en_ER
en_FI
en_FJ
en_FK
en_FM
en_GB
en_GD
en_GG
en_GH
en_GI
en_GM
en_GU
en_GY
en_HK
en_IE
en_IL
en_IM
en_IN
en_IO
en_JE
en_JM
en_KE
en_KI
en_KN
en_KY
en_LC
en_LR
en_LS
en_MG
en_MH
en_MO
en_MP
en_MS
en_MT
en_MU
en_MW
en_MY
en_NA
en_NF
en_NG
en_NL
en_NR
en_NU
en_NZ
en_PG
en_PH
en_PK
en_PN
en_PR
en_PW
en_RW
en_SB
en_SC
en_SD
en_SE
en_SG
en_SH
en_SI
en_SL
en_SS
en_SX
en_SZ
en_TC
en_TK
en_TO
en_TT
en_TV
en_TZ
en_UG
en_UM
en_US
en_US_POSIX
en_VC
en_VG
en_VI
en_VU
en_WS
en_ZA
en_ZM
en_ZW
eo
eo_001
es
es_419
es_AR
es_BO
es_CL
es_CO
es_CR
es_CU
es_DO
es_EA
es_EC
es_ES
es_GQ
es_GT
es_HN
es_IC
es_MX
es_NI
es_PA
es_PE
es_PH
es_PR
es_PY
es_SV
es_US
es_UY
es_VE
et
et_EE
eu
eu_ES
ewo
ewo_CM
fa
fa_AF
fa_IR
ff
ff_CM
ff_GN
ff_MR
ff_SN
fi
fi_FI
fil
fil_PH
fo
fo_DK
fo_FO
fr
fr_BE
fr_BF
fr_BI
fr_BJ
fr_BL
fr_CA
fr_CD
fr_CF
fr_CG
fr_CH
fr_CI
fr_CM
fr_DJ
fr_DZ
fr_FR
fr_GA
fr_GF
fr_GN
fr_GP
fr_GQ
fr_HT
fr_KM
fr_LU
fr_MA
fr_MC
fr_MF
fr_MG
fr_ML
fr_MQ
fr_MR
fr_MU
fr_NC
fr_NE
fr_PF
fr_PM
fr_RE
fr_RW
fr_SC
fr_SN
fr_SY
fr_TD
fr_TG
fr_TN
fr_VU
fr_WF
fr_YT
fur
fur_IT
fy
fy_NL
ga
ga_IE
gd
gd_GB
gl
gl_ES
gsw
gsw_CH
gsw_FR
gsw_LI
gu
gu_IN
guz
guz_KE
gv
gv_IM
ha
ha_GH
ha_NE
ha_NG
haw
haw_US
he
he_IL
hi
hi_IN
hr
hr_BA
hr_HR
hsb
hsb_DE
hu
hu_HU
hy
hy_AM
id
id_ID
ig
ig_NG
ii
ii_CN
is
is_IS
it
it_CH
it_IT
it_SM
ja
ja_JP
jgo
jgo_CM
jmc
jmc_TZ
ka
ka_GE
kab
kab_DZ
kam
kam_KE
kde
kde_TZ
kea
kea_CV
khq
khq_ML
ki
ki_KE
kk
kk_KZ
kkj
kkj_CM
kl
kl_GL
kln
kln_KE
km
km_KH
kn
kn_IN
ko
ko_KP
ko_KR
kok
kok_IN
ks
ks_IN
ksb
ksb_TZ
ksf
ksf_CM
ksh
ksh_DE
kw
kw_GB
ky
ky_KG
lag
lag_TZ
lb
lb_LU
lg
lg_UG
lkt
lkt_US
ln
ln_AO
ln_CD
ln_CF
ln_CG
lo
lo_LA
lrc
lrc_IQ
lrc_IR
lt
lt_LT
lu
lu_CD
luo
luo_KE
luy
luy_KE
lv
lv_LV
mas
mas_KE
mas_TZ
mer
mer_KE
mfe
mfe_MU
mg
mg_MG
mgh
mgh_MZ
mgo
mgo_CM
mk
mk_MK
ml
ml_IN
mn
mn_MN
mr
mr_IN
ms
ms_BN
ms_MY
ms_SG
mt
mt_MT
mua
mua_CM
my
my_MM
mzn
mzn_IR
naq
naq_NA
nb
nb_NO
nb_SJ
nd
nd_ZW
ne
ne_IN
ne_NP
nl
nl_AW
nl_BE
nl_BQ
nl_CW
nl_NL
nl_SR
nl_SX
nmg
nmg_CM
nn
nn_NO
nnh
nnh_CM
nus
nus_SS
nyn
nyn_UG
om
om_ET
om_KE
or
or_IN
os
os_GE
os_RU
pa
pa_Arab
pa_Arab_PK
pa_Guru
pa_Guru_IN
pl
pl_PL
prg
prg_001
ps
ps_AF
pt
pt_AO
pt_BR
pt_CV
pt_GW
pt_MO
pt_MZ
pt_PT
pt_ST
pt_TL
qu
qu_BO
qu_EC
qu_PE
rm
rm_CH
rn
rn_BI
ro
ro_MD
ro_RO
rof
rof_TZ
root
ru
ru_BY
ru_KG
ru_KZ
ru_MD
ru_RU
ru_UA
rw
rw_RW
rwk
rwk_TZ
sah
sah_RU
saq
saq_KE
sbp
sbp_TZ
se
se_FI
se_NO
se_SE
seh
seh_MZ
ses
ses_ML
sg
sg_CF
shi
shi_Latn
shi_Latn_MA
shi_Tfng
shi_Tfng_MA
si
si_LK
sk
sk_SK
sl
sl_SI
smn
smn_FI
sn
sn_ZW
so
so_DJ
so_ET
so_KE
so_SO
sq
sq_AL
sq_MK
sq_XK
sr
sr_Cyrl
sr_Cyrl_BA
sr_Cyrl_ME
sr_Cyrl_RS
sr_Cyrl_XK
sr_Latn
sr_Latn_BA
sr_Latn_ME
sr_Latn_RS
sr_Latn_XK
sv
sv_AX
sv_FI
sv_SE
sw
sw_CD
sw_KE
sw_TZ
sw_UG
ta
ta_IN
ta_LK
ta_MY
ta_SG
te
te_IN
teo
teo_KE
teo_UG
th
th_TH
ti
ti_ER
ti_ET
tk
tk_TM
to
to_TO
tr
tr_CY
tr_TR
twq
twq_NE
tzm
tzm_MA
ug
ug_CN
uk
uk_UA
ur
ur_IN
ur_PK
uz
uz_Arab
uz_Arab_AF
uz_Cyrl
uz_Cyrl_UZ
uz_Latn
uz_Latn_UZ
vai
vai_Latn
vai_Latn_LR
vai_Vaii
vai_Vaii_LR
vi
vi_VN
vo
vo_001
vun
vun_TZ
wae
wae_CH
xog
xog_UG
yav
yav_CM
yi
yi_001
yo
yo_BJ
yo_NG
zgh
zgh_MA
zh_Hans
zh_Hans_CN
zh_Hans_HK
zh_Hans_MO
zh_Hans_SG
zh_Hant
zh_Hant_HK
zh_Hant_MO
zh_Hant_TW
zu
zu_ZA
